# RoadMap

## Current limitations and planning fix

- currently `Anywise.send` does not provide accurate typing information, but annotated as return `typing.Any`
This have no runtime effect, but is a good to have feature.
It will be solved before anywise v1.0.0

- currently if a handler needs to receive `context`, it must declear the context parameter with name `context`, in future it will be decleared as type.

## FAQ

On its way here...
